pub struct SnapshotConfig {
pub max_events: Option<u32>,
pub max_age_days: Option<u32>,
}Expand description
Snapshot policy configuration
Fields
max_events: Option<u32>Create snapshot when events since last snapshot exceed this
max_age_days: Option<u32>Create snapshot when last snapshot is older than this many days