Module store

Module store 

Structs

DbStats
Statistics about the database
GritStore
Main storage interface backed by sled
IssueFilter
Filter for listing issues
LockedStore
A GritStore with filesystem-level exclusive lock.
RebuildStats
Statistics from a rebuild operation

Constants

DEFAULT_REBUILD_DAYS_THRESHOLD
Default threshold for days since rebuild before recommending rebuild
DEFAULT_REBUILD_EVENTS_THRESHOLD
Default threshold for events since rebuild before recommending rebuild